@@ -24,13 +24,22 @@ import sys
 
 import unittest
 from pygopherd import *
+import pygopherd.protocols
+import pygopherd.protocols.ProtocolMultiplexerTest
+import pygopherd.protocols.baseTest
+import pygopherd.protocols.rfc1436Test
+import pygopherd.protocols
 
 def suite():
     tests = [initializationTest,
              GopherExceptionsTest,
              fileextTest,
              gopherentryTest,
-             loggerTest
+             loggerTest,
+             pipeTest,
+             pygopherd.protocols.ProtocolMultiplexerTest,
+             pygopherd.protocols.baseTest,
+             pygopherd.protocols.rfc1436Test
         ]
     suite = unittest.TestSuite()
     for module in tests:
